
set more off
set matsize 1000

log using "replication_pof.log", replace

use "pof_web.dta", clear


local sam1 "logpgp95!=. & catho80!=.& muslim80!=. & notmcp80!=. & coal!=. & goldm!=. & iron!=. & silv!=. & zinc!=. & oilres!=. & humid1!=. & temp1!=. & steplow!=. & deslow!=. & stepmid!=. & desmid!=. &  drystep!=. & hiland!=. & drywint!=. & acdummy==1"



**************************************
***  Table 1:  Recreating AJR 2002 ***
**************************************


*** Urbanization ***
*Col 1
reg logpgp95 sjb1500 if  acdummy==1, rob

*Col 2
reg logpgp95 sjb1500 if `sam1' & aa_urb!=. , rob

*Col 3
reg logpgp95 aa_urb if `sam1' & aa_urb!=., rob


*** Population Density ***
*Col 4
reg logpgp95 lpd1500s if acdummy==1 , rob

*Col 5
reg logpgp95 lpd1500s if `sam1' & aa_pd!=., rob

*Col 6
reg logpgp95 aa_pd if `sam1' & aa_pd!=., rob


***********************************
*** Table 2: Correlation Matrix ***
***********************************

pwcorr sjb1500 lpd1500s ma sh_1500 tech1500 if acdummy==1, obs



******************************************************
*** Table 3: Persistence with Alternative Measures ***
******************************************************

*Col 1
reg logpgp95 ma if aa_ma!=. &  `sam1', rob

*Col 2
reg logpgp95 aa_ma if ma!=. & `sam1', rob

*Col 3
reg logpgp95 sh_1500 if aa_sh!=. & `sam1', rob

*Col 4
reg logpgp95 aa_sh if sh_1500!=. & `sam1', rob

*Col 5
reg logpgp95 tech1500 if  aa_tech!=. & `sam1', rob

*Col 6
reg logpgp95 aa_tech if tech1500!=. & `sam1', rob



************************************************
*** Table 4: Robustness to Omitted Variables ***
************************************************

local climate "humid* temp* steplow  deslow stepmid desmid  drystep hiland drywint"
local resources "coal landlock island goldm iron silv zinc oilres"
local co "f_french f_spain f_pothco f_dutch f_belg f_italy f_germ"
local religion "catho80 muslim80 notmcp80"


*** Panel A. Urbanization ***

*Latitude
reg logpgp95 sjb1500 lat_abst if aa_urb!=. & sjb1500!=. & `sam1', rob
reg logpgp95 aa_urb lat_abst if aa_urb!=. & sjb1500!=. & `sam1', rob

*Climate
reg logpgp95 sjb1500  `climate' if aa_urb!=. & sjb1500!=. & `sam1', rob
reg logpgp95 aa_urb   `climate' if aa_urb!=. & sjb1500!=. & `sam1', rob

*Resources
reg logpgp95 sjb1500 `resources' if aa_urb!=. & sjb1500!=. & `sam1', rob
reg logpgp95 aa_urb `resources' if aa_urb!=. & sjb1500!=. & `sam1', rob

*Colonizer
reg logpgp95 sjb1500 `co' if aa_urb!=. & sjb1500!=. & `sam1', rob
reg logpgp95 aa_urb `co' if aa_urb!=. & sjb1500!=. & `sam1', rob

*Religion
reg logpgp95 sjb1500 `religion' if aa_urb!=. & sjb1500!=. & `sam1', rob
reg logpgp95 aa_urb `religion' if aa_urb!=. & sjb1500!=. & `sam1', rob


*** Panel B. Population Density ***

*Latitude
reg logpgp95 lpd1500s lat_abst if aa_pd!=. & lpd1500s!=. & `sam1', rob
reg logpgp95 aa_pd lat_abst if aa_pd!=. & lpd1500s!=. & `sam1', rob


*Climate
reg logpgp95 lpd1500s  `climate' if aa_pd!=. & lpd1500s!=. & `sam1', rob
reg logpgp95 aa_pd   `climate' if aa_pd!=. & lpd1500s!=. & `sam1', rob

*Resources
reg logpgp95 lpd1500s `resources' if aa_pd!=. & lpd1500s!=. & `sam1', rob
reg logpgp95 aa_pd `resources' if aa_pd!=. & lpd1500s!=. & `sam1', rob

*Colonizer
reg logpgp95 lpd1500s `co' if aa_pd!=. & lpd1500s!=. & `sam1', rob
reg logpgp95 aa_pd `co' if aa_pd!=. & lpd1500s!=. & `sam1', rob

*Religion
reg logpgp95 lpd1500s `religion' if aa_pd!=. & lpd1500s!=. & `sam1', rob
reg logpgp95 aa_pd `religion' if aa_pd!=. & lpd1500s!=. & `sam1', rob


*** Panel C. Millennia of Agriculture ***

*Latitude
reg logpgp95 ma lat_abst if aa_ma!=. & ma!=. & `sam1', rob
reg logpgp95 aa_ma lat_abst if aa_ma!=. & ma!=. & `sam1', rob

*Climate
reg logpgp95 ma  `climate' if aa_ma!=. & ma!=. & `sam1', rob
reg logpgp95 aa_ma   `climate' if aa_ma!=. & ma!=. & `sam1', rob

*Resources
reg logpgp95 ma `resources' if aa_ma!=. & ma!=. & `sam1', rob
reg logpgp95 aa_ma `resources' if aa_ma!=. & ma!=. & `sam1', rob

*Colonizer
reg logpgp95 ma `co' if aa_ma!=. & ma!=. & `sam1', rob
reg logpgp95 aa_ma `co' if aa_ma!=. & ma!=. & `sam1', rob

*Religion
reg logpgp95 ma `religion' if aa_ma!=. & ma!=. & `sam1', rob
reg logpgp95 aa_ma `religion' if aa_ma!=. & ma!=. & `sam1', rob


*** Panel D. State History ***

*Latitude
reg logpgp95 sh_1500 lat_abst if aa_sh!=. & sh_1500!=. & `sam1', rob
reg logpgp95 aa_sh lat_abst if aa_sh!=. & sh_1500!=. & `sam1', rob

*Climate
reg logpgp95 sh_1500  `climate' if aa_sh!=. & sh_1500!=. & `sam1', rob
reg logpgp95 aa_sh   `climate' if aa_sh!=. & sh_1500!=. & `sam1', rob

*Resources
reg logpgp95 sh_1500 `resources' if aa_sh!=. & sh_1500!=. & `sam1', rob
reg logpgp95 aa_sh `resources' if aa_sh!=. & sh_1500!=. & `sam1', rob


*Colonizer
reg logpgp95 sh_1500 `co' if aa_sh!=. & sh_1500!=. & `sam1', rob
reg logpgp95 aa_sh `co' if aa_sh!=. & sh_1500!=. & `sam1', rob

*Religion
reg logpgp95 sh_1500 `religion' if aa_sh!=. & sh_1500!=. & `sam1', rob
reg logpgp95 aa_sh `religion' if aa_sh!=. & sh_1500!=. & `sam1', rob


*** Panel E. Technology ***

*Latitude
reg logpgp95 tech1500 lat_abst if aa_tech!=. & tech1500!=. & `sam1', rob
reg logpgp95 aa_tech lat_abst if aa_tech!=. & tech1500!=. & `sam1', rob

*Climate
reg logpgp95 tech1500  `climate' if aa_tech!=. & tech1500!=. & `sam1', rob
reg logpgp95 aa_tech   `climate' if aa_tech!=. & tech1500!=. & `sam1', rob

*Resources
reg logpgp95 tech1500 `resources' if aa_tech!=. & tech1500!=. & `sam1', rob
reg logpgp95 aa_tech `resources' if aa_tech!=. & tech1500!=. & `sam1', rob

*Colonizer
reg logpgp95 tech1500 `co' if aa_tech!=. & tech1500!=. & `sam1', rob
reg logpgp95 aa_tech `co' if aa_tech!=. & tech1500!=. & `sam1', rob

*Religion
reg logpgp95 tech1500 `religion' if aa_tech!=. & tech1500!=. & `sam1', rob
reg logpgp95 aa_tech `religion' if aa_tech!=. & tech1500!=. & `sam1', rob





************************************
*** Table 5: Alternative Samples ***
************************************

local ne "wbname!="United States" & wbname!="Canada" & wbname!="Australia" & wbname!="New Zealand" & wbname!="Singapore" & wbname!="Hong Kong, China" "
local sam2 "logpgp95!=. & catho80!=.& muslim80!=. & notmcp80!=. & coal!=. & goldm!=. & iron!=. & silv!=. & zinc!=. & oilres!=. & humid1!=. & temp1!=. & steplow!=. & deslow!=. & stepmid!=. & desmid!=. &  drystep!=. & hiland!=. & drywint!=. & europe==0"


*** Panel A. Urbanization ***

*Americas
reg logpgp95 sjb1500 if `sam1' & america==1  & aa_urb!=., rob
reg logpgp95 aa_urb if `sam1' & america==1  & sjb1500!=., rob

*High Immigration
reg logpgp95 sjb1500 if `sam1' & pown<.8 & aa_urb!=., rob
reg logpgp95 aa_urb if `sam1' & pown<.8 & sjb1500!=., rob

*Excluding Neo-Europes and City-States
reg logpgp95 sjb1500 if `sam1' & `ne' & aa_urb!=., rob
reg logpgp95 aa_urb if `sam1' & `ne' & sjb1500!=. , rob

*Including Non-Colonies (All non-European Countries)
reg logpgp95 sjb1500 if `sam2' & aa_urb!=., rob
reg logpgp95 aa_urb if `sam2' & sjb1500!=., rob


*** Panel B. Population Density ***

*Americas
reg logpgp95 lpd1500s if `sam1' & america==1  & aa_pd!=., rob
reg logpgp95 aa_pd if `sam1' & america==1  & lpd1500s!=., rob

*High Immigration
reg logpgp95 lpd1500s if `sam1' & pown<.8 & aa_pd!=., rob
reg logpgp95 aa_pd if `sam1' & pown<.8 & lpd1500s!=., rob

*Excluding Neo-Europes and City-States
reg logpgp95 lpd1500s if `sam1' & `ne' & aa_pd!=., rob
reg logpgp95 aa_pd if `sam1' & `ne' & lpd1500s!=. , rob

*Including Non-Colonies (All non-European Countries)
reg logpgp95 lpd1500s if `sam2' & aa_pd!=., rob
reg logpgp95 aa_pd if `sam2' & lpd1500s!=., rob



*** Panel C. Millennia of Agriculture ***

*Americas
reg logpgp95 ma if `sam1' & america==1  & aa_ma!=., rob
reg logpgp95 aa_ma if `sam1' & america==1  & ma!=., rob

*High Immigration
reg logpgp95 ma if `sam1' & pown<.8 & aa_ma!=., rob
reg logpgp95 aa_ma if `sam1' & pown<.8 & ma!=., rob

*Excluding Neo-Europes and City-States
reg logpgp95 ma if `sam1' & `ne' & aa_ma!=., rob
reg logpgp95 aa_ma if `sam1' & `ne' & ma!=. , rob

*Including Non-Colonies (All non-European Countries)
reg logpgp95 ma if `sam2' & aa_ma!=., rob
reg logpgp95 aa_ma if `sam2' & ma!=., rob


*** Panel D. State History ***

*Americas
reg logpgp95 sh_1500 if `sam1' & america==1  & aa_sh!=., rob
reg logpgp95 aa_sh if `sam1' & america==1  & sh_1500!=., rob

*High Immigration
reg logpgp95 sh_1500 if `sam1' & pown<.8 & aa_sh!=., rob
reg logpgp95 aa_sh if `sam1' & pown<.8 & sh_1500!=., rob

*Excluding Neo-Europes and City-States
reg logpgp95 sh_1500 if `sam1' & `ne' & aa_sh!=., rob
reg logpgp95 aa_sh if `sam1' & `ne' & sh_1500!=. , rob

*Including Non-Colonies (All non-European Countries)
reg logpgp95 sh_1500 if `sam2' & aa_sh!=., rob
reg logpgp95 aa_sh if `sam2' & sh_1500!=., rob


*** Panel E. Technology ***

*Americas
reg logpgp95 tech1500 if `sam1' & america==1  & aa_tech!=., rob
reg logpgp95 aa_tech if `sam1' & america==1  & tech1500!=., rob

*High Immigration
reg logpgp95 tech1500 if `sam1' & pown<.8 & aa_tech!=., rob
reg logpgp95 aa_tech if `sam1' & pown<.8 & tech1500!=., rob

*Excluding Neo-Europes and City-States
reg logpgp95 tech1500 if `sam1' & `ne' & aa_tech!=., rob
reg logpgp95 aa_tech if `sam1' & `ne' & tech1500!=. , rob

*Including Non-Colonies (All non-European Countries)
reg logpgp95 tech1500 if `sam2' & aa_tech!=., rob
reg logpgp95 aa_tech if `sam2' & tech1500!=., rob




**********************************
*** Table 6: Alternative Years ***
**********************************


*** Panel A. Urbanization ***

*1960
reg ln_ypc60 sjb1500 if `sam1' & aa60_urb!=., rob
reg ln_ypc60 aa60_urb if `sam1' & sjb1500!=., rob

*2009
reg ln_ypc09 sjb1500 if `sam1' & aa_urb!=., rob
reg ln_ypc09 aa_urb if `sam1'  & sjb1500!=., rob


*** Panel B. Population Density ***

*1960
reg ln_ypc60 lpd1500s if `sam1' & aa60_pd!=., rob
reg ln_ypc60 aa60_pd if `sam1' & lpd1500s!=., rob

*2009
reg ln_ypc09 lpd1500s if `sam1' & aa_pd!=., rob
reg ln_ypc09 aa_pd if `sam1'  & lpd1500s!=., rob


*** Panel C. Millennia of Agriculture ***

*1960
reg ln_ypc60 ma if `sam1' & aa60_ma!=., rob
reg ln_ypc60 aa60_ma if `sam1' & ma!=., rob

*2009
reg ln_ypc09 ma if `sam1' & aa_ma!=., rob
reg ln_ypc09 aa_ma if `sam1'  & ma!=., rob


*** Panel D. State History ***

*1960
reg ln_ypc60 sh_1500 if `sam1' & aa60_sh!=., rob
reg ln_ypc60 aa60_sh if `sam1' & sh_1500!=., rob

*2009
reg ln_ypc09 sh_1500 if `sam1' & aa_sh!=., rob
reg ln_ypc09 aa_sh if `sam1'  & sh_1500!=., rob


*** Panel E. Technology ***

*1960
reg ln_ypc60 tech1500 if `sam1' & aa60_tech!=., rob
reg ln_ypc60 aa60_tech if `sam1' & tech1500!=., rob

*2009
reg ln_ypc09 tech1500 if `sam1' & aa_tech!=., rob
reg ln_ypc09 aa_tech if `sam1'  & tech1500!=., rob




****************************************
*** Table 7: Channels of Persistence ***
****************************************

local ua "lpd1500s ma sh_1500 tech1500"
local mw "aa_pd aa_ma aa_sh aa_tech"
local s2 "lpd1500s!=. & aa_pd!=. & aa_ma!=. & ma!=. & sh_1500!=. & aa_sh!=. & tech1500!=. & aa_tech!=."

*Col 1
ivreg2 logpgp95 (avexpr = `mw' `ua') if `s2' & `sam1' & lit50!=., rob small first

*Col 2
ivreg2 logpgp95 (lit50 = `mw' `ua') if `s2' & `sam'1 & avexpr!=., rob small first

*Col 3
ivreg2 logpgp95 (avexpr lit50 = `mw' `ua') if `s2' & `sam1', rob small first

*Col 4
ivreg2 logpgp95 (cons50 lit50 = `mw' `ua') if `s2' & `sam1' , rob small first

*Col 5
ivreg2 logpgp95 (cons75 lit70 = `mw' `ua') if `s2' & `sam1' , rob small first

*Col 6
ivreg2 logpgp95 (avglit_8595 = `mw' `ua') if `s2' & `sam1' & cons90!=. , rob small first

*Col 7
ivreg2 logpgp95 (cons90 avglit_8595 = `mw' `ua') if `s2' & `sam1' , rob small first

*Col 8
ivreg2 logpgp95 (avexpr avglit_8595 = `mw' `ua') if `s2' & `sam1' , rob small first

*Col 9
ivreg2 logpgp95 (avexpr avg_yrsch_8595 = `mw' `ua') if `s2' & `sam1' , rob small first

*Col 10
ivreg2 logpgp95 (wgi96 lit50 = `mw' `ua') if `s2' & `sam1', rob small first



log close

